# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.propertymappings_api import PropertymappingsApi


class TestPropertymappingsApi(unittest.TestCase):
    """PropertymappingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PropertymappingsApi()

    def tearDown(self) -> None:
        pass

    def test_propertymappings_all_destroy(self) -> None:
        """Test case for propertymappings_all_destroy

        """
        pass

    def test_propertymappings_all_list(self) -> None:
        """Test case for propertymappings_all_list

        """
        pass

    def test_propertymappings_all_retrieve(self) -> None:
        """Test case for propertymappings_all_retrieve

        """
        pass

    def test_propertymappings_all_test_create(self) -> None:
        """Test case for propertymappings_all_test_create

        """
        pass

    def test_propertymappings_all_types_list(self) -> None:
        """Test case for propertymappings_all_types_list

        """
        pass

    def test_propertymappings_all_used_by_list(self) -> None:
        """Test case for propertymappings_all_used_by_list

        """
        pass

    def test_propertymappings_notification_create(self) -> None:
        """Test case for propertymappings_notification_create

        """
        pass

    def test_propertymappings_notification_destroy(self) -> None:
        """Test case for propertymappings_notification_destroy

        """
        pass

    def test_propertymappings_notification_list(self) -> None:
        """Test case for propertymappings_notification_list

        """
        pass

    def test_propertymappings_notification_partial_update(self) -> None:
        """Test case for propertymappings_notification_partial_update

        """
        pass

    def test_propertymappings_notification_retrieve(self) -> None:
        """Test case for propertymappings_notification_retrieve

        """
        pass

    def test_propertymappings_notification_update(self) -> None:
        """Test case for propertymappings_notification_update

        """
        pass

    def test_propertymappings_notification_used_by_list(self) -> None:
        """Test case for propertymappings_notification_used_by_list

        """
        pass

    def test_propertymappings_provider_google_workspace_create(self) -> None:
        """Test case for propertymappings_provider_google_workspace_create

        """
        pass

    def test_propertymappings_provider_google_workspace_destroy(self) -> None:
        """Test case for propertymappings_provider_google_workspace_destroy

        """
        pass

    def test_propertymappings_provider_google_workspace_list(self) -> None:
        """Test case for propertymappings_provider_google_workspace_list

        """
        pass

    def test_propertymappings_provider_google_workspace_partial_update(self) -> None:
        """Test case for propertymappings_provider_google_workspace_partial_update

        """
        pass

    def test_propertymappings_provider_google_workspace_retrieve(self) -> None:
        """Test case for propertymappings_provider_google_workspace_retrieve

        """
        pass

    def test_propertymappings_provider_google_workspace_update(self) -> None:
        """Test case for propertymappings_provider_google_workspace_update

        """
        pass

    def test_propertymappings_provider_google_workspace_used_by_list(self) -> None:
        """Test case for propertymappings_provider_google_workspace_used_by_list

        """
        pass

    def test_propertymappings_provider_microsoft_entra_create(self) -> None:
        """Test case for propertymappings_provider_microsoft_entra_create

        """
        pass

    def test_propertymappings_provider_microsoft_entra_destroy(self) -> None:
        """Test case for propertymappings_provider_microsoft_entra_destroy

        """
        pass

    def test_propertymappings_provider_microsoft_entra_list(self) -> None:
        """Test case for propertymappings_provider_microsoft_entra_list

        """
        pass

    def test_propertymappings_provider_microsoft_entra_partial_update(self) -> None:
        """Test case for propertymappings_provider_microsoft_entra_partial_update

        """
        pass

    def test_propertymappings_provider_microsoft_entra_retrieve(self) -> None:
        """Test case for propertymappings_provider_microsoft_entra_retrieve

        """
        pass

    def test_propertymappings_provider_microsoft_entra_update(self) -> None:
        """Test case for propertymappings_provider_microsoft_entra_update

        """
        pass

    def test_propertymappings_provider_microsoft_entra_used_by_list(self) -> None:
        """Test case for propertymappings_provider_microsoft_entra_used_by_list

        """
        pass

    def test_propertymappings_provider_rac_create(self) -> None:
        """Test case for propertymappings_provider_rac_create

        """
        pass

    def test_propertymappings_provider_rac_destroy(self) -> None:
        """Test case for propertymappings_provider_rac_destroy

        """
        pass

    def test_propertymappings_provider_rac_list(self) -> None:
        """Test case for propertymappings_provider_rac_list

        """
        pass

    def test_propertymappings_provider_rac_partial_update(self) -> None:
        """Test case for propertymappings_provider_rac_partial_update

        """
        pass

    def test_propertymappings_provider_rac_retrieve(self) -> None:
        """Test case for propertymappings_provider_rac_retrieve

        """
        pass

    def test_propertymappings_provider_rac_update(self) -> None:
        """Test case for propertymappings_provider_rac_update

        """
        pass

    def test_propertymappings_provider_rac_used_by_list(self) -> None:
        """Test case for propertymappings_provider_rac_used_by_list

        """
        pass

    def test_propertymappings_provider_radius_create(self) -> None:
        """Test case for propertymappings_provider_radius_create

        """
        pass

    def test_propertymappings_provider_radius_destroy(self) -> None:
        """Test case for propertymappings_provider_radius_destroy

        """
        pass

    def test_propertymappings_provider_radius_list(self) -> None:
        """Test case for propertymappings_provider_radius_list

        """
        pass

    def test_propertymappings_provider_radius_partial_update(self) -> None:
        """Test case for propertymappings_provider_radius_partial_update

        """
        pass

    def test_propertymappings_provider_radius_retrieve(self) -> None:
        """Test case for propertymappings_provider_radius_retrieve

        """
        pass

    def test_propertymappings_provider_radius_update(self) -> None:
        """Test case for propertymappings_provider_radius_update

        """
        pass

    def test_propertymappings_provider_radius_used_by_list(self) -> None:
        """Test case for propertymappings_provider_radius_used_by_list

        """
        pass

    def test_propertymappings_provider_saml_create(self) -> None:
        """Test case for propertymappings_provider_saml_create

        """
        pass

    def test_propertymappings_provider_saml_destroy(self) -> None:
        """Test case for propertymappings_provider_saml_destroy

        """
        pass

    def test_propertymappings_provider_saml_list(self) -> None:
        """Test case for propertymappings_provider_saml_list

        """
        pass

    def test_propertymappings_provider_saml_partial_update(self) -> None:
        """Test case for propertymappings_provider_saml_partial_update

        """
        pass

    def test_propertymappings_provider_saml_retrieve(self) -> None:
        """Test case for propertymappings_provider_saml_retrieve

        """
        pass

    def test_propertymappings_provider_saml_update(self) -> None:
        """Test case for propertymappings_provider_saml_update

        """
        pass

    def test_propertymappings_provider_saml_used_by_list(self) -> None:
        """Test case for propertymappings_provider_saml_used_by_list

        """
        pass

    def test_propertymappings_provider_scim_create(self) -> None:
        """Test case for propertymappings_provider_scim_create

        """
        pass

    def test_propertymappings_provider_scim_destroy(self) -> None:
        """Test case for propertymappings_provider_scim_destroy

        """
        pass

    def test_propertymappings_provider_scim_list(self) -> None:
        """Test case for propertymappings_provider_scim_list

        """
        pass

    def test_propertymappings_provider_scim_partial_update(self) -> None:
        """Test case for propertymappings_provider_scim_partial_update

        """
        pass

    def test_propertymappings_provider_scim_retrieve(self) -> None:
        """Test case for propertymappings_provider_scim_retrieve

        """
        pass

    def test_propertymappings_provider_scim_update(self) -> None:
        """Test case for propertymappings_provider_scim_update

        """
        pass

    def test_propertymappings_provider_scim_used_by_list(self) -> None:
        """Test case for propertymappings_provider_scim_used_by_list

        """
        pass

    def test_propertymappings_provider_scope_create(self) -> None:
        """Test case for propertymappings_provider_scope_create

        """
        pass

    def test_propertymappings_provider_scope_destroy(self) -> None:
        """Test case for propertymappings_provider_scope_destroy

        """
        pass

    def test_propertymappings_provider_scope_list(self) -> None:
        """Test case for propertymappings_provider_scope_list

        """
        pass

    def test_propertymappings_provider_scope_partial_update(self) -> None:
        """Test case for propertymappings_provider_scope_partial_update

        """
        pass

    def test_propertymappings_provider_scope_retrieve(self) -> None:
        """Test case for propertymappings_provider_scope_retrieve

        """
        pass

    def test_propertymappings_provider_scope_update(self) -> None:
        """Test case for propertymappings_provider_scope_update

        """
        pass

    def test_propertymappings_provider_scope_used_by_list(self) -> None:
        """Test case for propertymappings_provider_scope_used_by_list

        """
        pass

    def test_propertymappings_source_kerberos_create(self) -> None:
        """Test case for propertymappings_source_kerberos_create

        """
        pass

    def test_propertymappings_source_kerberos_destroy(self) -> None:
        """Test case for propertymappings_source_kerberos_destroy

        """
        pass

    def test_propertymappings_source_kerberos_list(self) -> None:
        """Test case for propertymappings_source_kerberos_list

        """
        pass

    def test_propertymappings_source_kerberos_partial_update(self) -> None:
        """Test case for propertymappings_source_kerberos_partial_update

        """
        pass

    def test_propertymappings_source_kerberos_retrieve(self) -> None:
        """Test case for propertymappings_source_kerberos_retrieve

        """
        pass

    def test_propertymappings_source_kerberos_update(self) -> None:
        """Test case for propertymappings_source_kerberos_update

        """
        pass

    def test_propertymappings_source_kerberos_used_by_list(self) -> None:
        """Test case for propertymappings_source_kerberos_used_by_list

        """
        pass

    def test_propertymappings_source_ldap_create(self) -> None:
        """Test case for propertymappings_source_ldap_create

        """
        pass

    def test_propertymappings_source_ldap_destroy(self) -> None:
        """Test case for propertymappings_source_ldap_destroy

        """
        pass

    def test_propertymappings_source_ldap_list(self) -> None:
        """Test case for propertymappings_source_ldap_list

        """
        pass

    def test_propertymappings_source_ldap_partial_update(self) -> None:
        """Test case for propertymappings_source_ldap_partial_update

        """
        pass

    def test_propertymappings_source_ldap_retrieve(self) -> None:
        """Test case for propertymappings_source_ldap_retrieve

        """
        pass

    def test_propertymappings_source_ldap_update(self) -> None:
        """Test case for propertymappings_source_ldap_update

        """
        pass

    def test_propertymappings_source_ldap_used_by_list(self) -> None:
        """Test case for propertymappings_source_ldap_used_by_list

        """
        pass

    def test_propertymappings_source_oauth_create(self) -> None:
        """Test case for propertymappings_source_oauth_create

        """
        pass

    def test_propertymappings_source_oauth_destroy(self) -> None:
        """Test case for propertymappings_source_oauth_destroy

        """
        pass

    def test_propertymappings_source_oauth_list(self) -> None:
        """Test case for propertymappings_source_oauth_list

        """
        pass

    def test_propertymappings_source_oauth_partial_update(self) -> None:
        """Test case for propertymappings_source_oauth_partial_update

        """
        pass

    def test_propertymappings_source_oauth_retrieve(self) -> None:
        """Test case for propertymappings_source_oauth_retrieve

        """
        pass

    def test_propertymappings_source_oauth_update(self) -> None:
        """Test case for propertymappings_source_oauth_update

        """
        pass

    def test_propertymappings_source_oauth_used_by_list(self) -> None:
        """Test case for propertymappings_source_oauth_used_by_list

        """
        pass

    def test_propertymappings_source_plex_create(self) -> None:
        """Test case for propertymappings_source_plex_create

        """
        pass

    def test_propertymappings_source_plex_destroy(self) -> None:
        """Test case for propertymappings_source_plex_destroy

        """
        pass

    def test_propertymappings_source_plex_list(self) -> None:
        """Test case for propertymappings_source_plex_list

        """
        pass

    def test_propertymappings_source_plex_partial_update(self) -> None:
        """Test case for propertymappings_source_plex_partial_update

        """
        pass

    def test_propertymappings_source_plex_retrieve(self) -> None:
        """Test case for propertymappings_source_plex_retrieve

        """
        pass

    def test_propertymappings_source_plex_update(self) -> None:
        """Test case for propertymappings_source_plex_update

        """
        pass

    def test_propertymappings_source_plex_used_by_list(self) -> None:
        """Test case for propertymappings_source_plex_used_by_list

        """
        pass

    def test_propertymappings_source_saml_create(self) -> None:
        """Test case for propertymappings_source_saml_create

        """
        pass

    def test_propertymappings_source_saml_destroy(self) -> None:
        """Test case for propertymappings_source_saml_destroy

        """
        pass

    def test_propertymappings_source_saml_list(self) -> None:
        """Test case for propertymappings_source_saml_list

        """
        pass

    def test_propertymappings_source_saml_partial_update(self) -> None:
        """Test case for propertymappings_source_saml_partial_update

        """
        pass

    def test_propertymappings_source_saml_retrieve(self) -> None:
        """Test case for propertymappings_source_saml_retrieve

        """
        pass

    def test_propertymappings_source_saml_update(self) -> None:
        """Test case for propertymappings_source_saml_update

        """
        pass

    def test_propertymappings_source_saml_used_by_list(self) -> None:
        """Test case for propertymappings_source_saml_used_by_list

        """
        pass

    def test_propertymappings_source_scim_create(self) -> None:
        """Test case for propertymappings_source_scim_create

        """
        pass

    def test_propertymappings_source_scim_destroy(self) -> None:
        """Test case for propertymappings_source_scim_destroy

        """
        pass

    def test_propertymappings_source_scim_list(self) -> None:
        """Test case for propertymappings_source_scim_list

        """
        pass

    def test_propertymappings_source_scim_partial_update(self) -> None:
        """Test case for propertymappings_source_scim_partial_update

        """
        pass

    def test_propertymappings_source_scim_retrieve(self) -> None:
        """Test case for propertymappings_source_scim_retrieve

        """
        pass

    def test_propertymappings_source_scim_update(self) -> None:
        """Test case for propertymappings_source_scim_update

        """
        pass

    def test_propertymappings_source_scim_used_by_list(self) -> None:
        """Test case for propertymappings_source_scim_used_by_list

        """
        pass

    def test_propertymappings_source_telegram_create(self) -> None:
        """Test case for propertymappings_source_telegram_create

        """
        pass

    def test_propertymappings_source_telegram_destroy(self) -> None:
        """Test case for propertymappings_source_telegram_destroy

        """
        pass

    def test_propertymappings_source_telegram_list(self) -> None:
        """Test case for propertymappings_source_telegram_list

        """
        pass

    def test_propertymappings_source_telegram_partial_update(self) -> None:
        """Test case for propertymappings_source_telegram_partial_update

        """
        pass

    def test_propertymappings_source_telegram_retrieve(self) -> None:
        """Test case for propertymappings_source_telegram_retrieve

        """
        pass

    def test_propertymappings_source_telegram_update(self) -> None:
        """Test case for propertymappings_source_telegram_update

        """
        pass

    def test_propertymappings_source_telegram_used_by_list(self) -> None:
        """Test case for propertymappings_source_telegram_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
